"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.diffCollectionsSync = exports.getBlobDownloadUrl = exports.unzipFile = exports.createEmptyFolderSync = exports.createEmptyFolder = exports.deleteFolderSync = exports.copy = exports.copySync = exports.createFileFromRequest = exports.validatorVersion = exports.parseVersion = void 0;
/* eslint-disable no-cond-assign */
const fs_1 = __importDefault(require("fs"));
const stream_1 = require("stream");
const util_1 = __importDefault(require("util"));
const extract_zip_1 = __importDefault(require("extract-zip"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const lodash_1 = __importDefault(require("lodash"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const validator_1 = __importDefault(require("validator"));
const app_error_1 = require("../app-error");
const config_1 = require("../config");
const streamPipeline = util_1.default.promisify(stream_1.pipeline);
function parseVersion(versionNo) {
    let version = '0';
    let data = null;
    if ((data = versionNo.match(/^([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // "1.2.3"
        version = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
    }
    else if ((data = versionNo.match(/^([0-9]{1,3}).([0-9]{1,5})$/))) {
        // "1.2"
        version = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart('0', 10, '0');
    }
    return version;
}
exports.parseVersion = parseVersion;
function validatorVersion(versionNo) {
    let flag = false;
    let min = '0';
    let max = '9999999999999999999';
    let data = null;
    if (versionNo === '*') {
        // "*"
        flag = true;
    }
    else if ((data = versionNo.match(/^([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // "1.2.3"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
        max =
            data[1] +
                lodash_1.default.padStart(data[2], 5, '0') +
                lodash_1.default.padStart(`${parseInt(data[3], 10) + 1}`, 10, '0');
    }
    else if ((data = versionNo.match(/^([0-9]{1,3}).([0-9]{1,5})(\.\*){0,1}$/))) {
        // "1.2" "1.2.*"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart('0', 10, '0');
        max =
            data[1] + lodash_1.default.padStart(`${parseInt(data[2], 10) + 1}`, 5, '0') + lodash_1.default.padStart('0', 10, '0');
    }
    else if ((data = versionNo.match(/^~([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // "~1.2.3"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
        max =
            data[1] + lodash_1.default.padStart(`${parseInt(data[2], 10) + 1}`, 5, '0') + lodash_1.default.padStart('0', 10, '0');
    }
    else if ((data = versionNo.match(/^\^([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // "^1.2.3"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
        max =
            lodash_1.default.toString(parseInt(data[1], 10) + 1) +
                lodash_1.default.padStart('0', 5, '0') +
                lodash_1.default.padStart('0', 10, '0');
    }
    else if ((data = versionNo.match(/^([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})\s?-\s?([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // "1.2.3 - 1.2.7"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
        max =
            data[4] +
                lodash_1.default.padStart(data[5], 5, '0') +
                lodash_1.default.padStart(`${parseInt(data[6], 10) + 1}`, 10, '0');
    }
    else if ((data = versionNo.match(/^>=([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})\s?<([0-9]{1,3}).([0-9]{1,5}).([0-9]{1,10})$/))) {
        // ">=1.2.3 <1.2.7"
        flag = true;
        min = data[1] + lodash_1.default.padStart(data[2], 5, '0') + lodash_1.default.padStart(data[3], 10, '0');
        max = data[4] + lodash_1.default.padStart(data[5], 5, '0') + lodash_1.default.padStart(data[6], 10, '0');
    }
    return [flag, min, max];
}
exports.validatorVersion = validatorVersion;
async function createFileFromRequest(url, filePath, logger) {
    try {
        await fs_1.default.promises.stat(filePath);
        return;
    }
    catch (err) {
        if (err.code !== 'ENOENT') {
            throw err;
        }
    }
    logger.debug(`createFileFromRequest url:${url}`);
    const response = await (0, node_fetch_1.default)(url);
    console.log('res======1=======',response)
    if (!response.ok) {
        throw new app_error_1.AppError(`unexpected response ${response.statusText}`);
    }
    await streamPipeline(response.body, fs_1.default.createWriteStream(filePath));
}
exports.createFileFromRequest = createFileFromRequest;
function copySync(sourceDst, targertDst) {
    return fs_extra_1.default.copySync(sourceDst, targertDst, { overwrite: true });
}
exports.copySync = copySync;
function copy(sourceDst, targertDst) {
    return fs_extra_1.default.copy(sourceDst, targertDst, { overwrite: true });
}
exports.copy = copy;
function deleteFolder(folderPath) {
    return fs_extra_1.default.remove(folderPath);
}
function deleteFolderSync(folderPath) {
    return fs_extra_1.default.removeSync(folderPath);
}
exports.deleteFolderSync = deleteFolderSync;
async function createEmptyFolder(folderPath) {
    await deleteFolder(folderPath);
    await fs_extra_1.default.mkdirs(folderPath);
}
exports.createEmptyFolder = createEmptyFolder;
function createEmptyFolderSync(folderPath) {
    deleteFolderSync(folderPath);
    fs_extra_1.default.mkdirsSync(folderPath);
}
exports.createEmptyFolderSync = createEmptyFolderSync;
async function unzipFile(zipFile, outputPath, logger) {
    try {
        logger.debug(`unzipFile check zipFile ${zipFile} fs.R_OK`);
        fs_1.default.accessSync(zipFile, fs_1.default.constants.R_OK);
        logger.debug(`Pass unzipFile file ${zipFile}`);
    }
    catch (err) {
        throw new app_error_1.AppError(err.message);
    }
    try {
        await (0, extract_zip_1.default)(zipFile, { dir: outputPath });
        logger.debug(`unzipFile success`);
    }
    catch (err) {
        throw new app_error_1.AppError(`it's not a zipFile`);
    }
    return outputPath;
}
exports.unzipFile = unzipFile;
function getBlobDownloadUrl(blobUrl) {
    let fileName = blobUrl;
    const { storageType } = config_1.config.common;
    const { downloadUrl } = config_1.config[storageType];
    if (storageType === 'local') {
        fileName = `${blobUrl.substring(0, 2).toLowerCase()}/${blobUrl}`;
    }
    if (!validator_1.default.isURL(downloadUrl)) {
        throw new app_error_1.AppError(`Please config ${storageType}.downloadUrl in config.js`);
    }
    return `${downloadUrl}/${fileName}`;
}
exports.getBlobDownloadUrl = getBlobDownloadUrl;
function diffCollectionsSync(collection1, collection2) {
    const diff = [];
    const collection1Only = [];
    const collection2Keys = new Set(Object.keys(collection2));
    if (collection1 instanceof Object) {
        const keys = Object.keys(collection1);
        for (let i = 0; i < keys.length; i += 1) {
            const key = keys[i];
            if (!collection2Keys.has(key)) {
                collection1Only.push(key);
            }
            else {
                collection2Keys.delete(key);
                if (!lodash_1.default.eq(collection1[key], collection2[key])) {
                    diff.push(key);
                }
            }
        }
    }
    return {
        diff,
        collection1Only,
        collection2Only: Array.from(collection2Keys),
    };
}
exports.diffCollectionsSync = diffCollectionsSync;
