"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDeploymentsLabelId = exports.Deployments = void 0;
const lodash_1 = __importDefault(require("lodash"));
const sequelize_1 = require("sequelize");
const app_error_1 = require("../core/app-error");
const connections_1 = require("../core/utils/connections");
exports.Deployments = connections_1.sequelize.define('Deployments', {
    id: {
        type: sequelize_1.DataTypes.INTEGER({ length: 10 }),
        allowNull: false,
        autoIncrement: true,
        primaryKey: true,
    },
    appid: sequelize_1.DataTypes.INTEGER({ length: 10 }),
    name: sequelize_1.DataTypes.STRING,
    description: sequelize_1.DataTypes.STRING,
    deployment_key: sequelize_1.DataTypes.STRING,
    last_deployment_version_id: sequelize_1.DataTypes.INTEGER({ length: 10 }),
    label_id: sequelize_1.DataTypes.INTEGER({ length: 10 }),
    created_at: sequelize_1.DataTypes.DATE,
    updated_at: sequelize_1.DataTypes.DATE,
}, {
    tableName: 'deployments',
    underscored: true,
    paranoid: true,
});
function generateDeploymentsLabelId(deploymentId) {
    return connections_1.sequelize.transaction((t) => {
        return exports.Deployments.findByPk(deploymentId, {
            transaction: t,
            lock: t.LOCK.UPDATE,
        }).then((data) => {
            if (lodash_1.default.isEmpty(data)) {
                throw new app_error_1.AppError('does not find deployment');
            }
            data.label_id += 1;
            return data.save({ transaction: t }).then((d) => {
                return d.label_id;
            });
        });
    });
}
exports.generateDeploymentsLabelId = generateDeploymentsLabelId;
