"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.indexV1Router = void 0;
const express_1 = __importDefault(require("express"));
const app_error_1 = require("../core/app-error");
const client_manager_1 = require("../core/services/client-manager");
// routes for latest code push client
exports.indexV1Router = express_1.default.Router();
exports.indexV1Router.get('/update_check', (req, res, next) => {
    const { logger, query } = req;
    logger.info('try update_check', {
        query: JSON.stringify(query),
    });
    const { deployment_key: deploymentKey, app_version: appVersion, label, package_hash: packageHash, client_unique_id: clientUniqueId, } = query;
    client_manager_1.clientManager
        .updateCheckFromCache(deploymentKey, appVersion, label, packageHash, clientUniqueId, logger)
        .then((rs) => {
        // 灰度检测
        return client_manager_1.clientManager
            .chosenMan(rs.packageId, rs.rollout, clientUniqueId)
            .then((data) => {
            if (!data) {
                rs.isAvailable = false;
                return rs;
            }
            return rs;
        });
    })
        .then((rs) => {
        logger.info('update_check success');
        res.send({
            update_info: {
                download_url: rs.downloadUrl,
                description: rs.description,
                is_available: rs.isAvailable,
                is_disabled: rs.isDisabled,
                // Note: need to use appVersion here to get it compatible with client side change...
                // https://github.com/microsoft/code-push/commit/7d2ffff395cc54db98aefba7c67889f509e8c249#diff-a937c637a47cbd31cbb52c89bef7d197R138
                target_binary_range: rs.appVersion,
                label: rs.label,
                package_hash: rs.packageHash,
                package_size: rs.packageSize,
                should_run_binary_version: rs.shouldRunBinaryVersion,
                update_app_version: rs.updateAppVersion,
                is_mandatory: rs.isMandatory,
            },
        });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            logger.info('update check failed', {
                error: e.message,
            });
            res.status(404).send(e.message);
        }
        else {
            next(e);
        }
    });
});
exports.indexV1Router.post('/report_status/download', (req, res) => {
    const { logger, body } = req;
    logger.info('report_status/download', { body: JSON.stringify(body) });
    const { client_unique_id: clientUniqueId, label, deployment_key: deploymentKey } = body;
    client_manager_1.clientManager.reportStatusDownload(deploymentKey, label, clientUniqueId).catch((err) => {
        if (err instanceof app_error_1.AppError) {
            logger.info('report_status/download failed', {
                error: err.message,
            });
        }
        else {
            logger.error(err);
        }
    });
    res.send('OK');
});
exports.indexV1Router.post('/report_status/deploy', (req, res) => {
    const { logger, body } = req;
    logger.info('report_status/deploy', { body: JSON.stringify(body) });
    const { client_unique_id: clientUniqueId, label, deployment_key: deploymentKey } = body;
    client_manager_1.clientManager
        .reportStatusDeploy(deploymentKey, label, clientUniqueId, req.body)
        .catch((err) => {
        if (err instanceof app_error_1.AppError) {
            logger.info('report_status/deploy failed', {
                error: err.message,
            });
        }
        else {
            logger.error(err);
        }
    });
    res.send('OK');
});
