"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usersRouter = void 0;
const express_1 = __importDefault(require("express"));
const lodash_1 = __importDefault(require("lodash"));
const app_error_1 = require("../core/app-error");
const middleware_1 = require("../core/middleware");
const account_manager_1 = require("../core/services/account-manager");
const users_1 = require("../models/users");
exports.usersRouter = express_1.default.Router();
exports.usersRouter.get('/', middleware_1.checkToken, (req, res) => {
    res.send({ title: 'CodePushServer' });
});
exports.usersRouter.post('/', (req, res, next) => {
    const { logger, body } = req;
    const email = lodash_1.default.trim(body.email);
    const token = lodash_1.default.trim(body.token);
    const password = lodash_1.default.trim(body.password);
    logger.info('try register account', { email, token });
    return account_manager_1.accountManager
        .checkRegisterCode(email, token)
        .then(() => {
        if (lodash_1.default.isString(password) && password.length < 6) {
            throw new app_error_1.AppError('请您输入6～20位长度的密码');
        }
        return account_manager_1.accountManager.register(email, password);
    })
        .then(() => {
        logger.info('register account success', { email });
        res.send({ status: 'OK' });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            logger.info('register account failed', { email, error: e.message });
            res.send({ status: 'ERROR', message: e.message });
        }
        else {
            next(e);
        }
    });
});
exports.usersRouter.get('/exists', (req, res, next) => {
    const email = lodash_1.default.trim(req.query.email);
    if (!email) {
        res.send({ status: 'ERROR', message: '请您输入邮箱地址' });
        return;
    }
    users_1.Users.findOne({ where: { email } })
        .then((u) => {
        res.send({ status: 'OK', exists: !!u });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            res.send({ status: 'ERROR', message: e.message });
        }
        else {
            next(e);
        }
    });
});
exports.usersRouter.post('/registerCode', (req, res, next) => {
    const { logger, body } = req;
    const { email } = body;
    logger.info('try send register code', { email });
    return account_manager_1.accountManager
        .sendRegisterCode(email)
        .then(() => {
        logger.info('send register code success', { email });
        res.send({ status: 'OK' });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            logger.info('send register code error', { email, error: e.message });
            res.send({ status: 'ERROR', message: e.message });
        }
        else {
            next(e);
        }
    });
});
exports.usersRouter.get('/registerCode/exists', (req, res, next) => {
    const { query } = req;
    const email = lodash_1.default.trim(query.email);
    const token = lodash_1.default.trim(query.token);
    return res.send({status:'OK'})
    /*return account_manager_1.accountManager
        .checkRegisterCode(email, token)
        .then(() => {
        res.send({ status: 'OK' });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            res.send({ status: 'ERROR', message: e.message });
        }
        else {
            next(e);
        }
    });*/
});
// 修改密码
exports.usersRouter.patch('/password', middleware_1.checkToken, (req, res, next) => {
    const { logger, body } = req;
    const oldPassword = lodash_1.default.trim(body.oldPassword);
    const newPassword = lodash_1.default.trim(body.newPassword);
    const uid = req.users.id;
    logger.info('try change password', { uid });
    return account_manager_1.accountManager
        .changePassword(uid, oldPassword, newPassword)
        .then(() => {
        logger.info('change password success', { uid });
        res.send({ status: 'OK' });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            logger.info('change password failed', { uid });
            res.send({ status: 'ERROR', message: e.message });
        }
        else {
            next(e);
        }
    });
});
